@@ -4,13 +4,13 @@ import markdown as mdgen
 from datetime import datetime
 import webbrowser as browser
 from blmarkdown.App import App
-from blmarkdown.Flavor import Flavor
+from blmarkdown.Preview import Preview
 
 __author__ = 'Haryo Bagas Assyafah'
 __copyright__ = 'Bear Au Jus - ジュースとくま @2021'
 __credits__ = ['Haryo Bagas Assyafah']
 __license__ = "MIT"
-__version__ = "2.2"
+__version__ = "2.3"
 __maintainer__ = "Haryo Bagas Assyafah"
 __email__ = "haryobagasasyafah6@gmail.com"
 __status__ = "Production"
@@ -124,11 +124,11 @@ class Utill:
 
     @staticmethod
     def get_css():
-        return Flavor.get_css()
+        return Preview.get_css()
 
     @staticmethod
     def get_js():
-        return Flavor.get_js()
+        return Preview.get_js()
 
     # ETC Function =================================================================================================
     @ staticmethod
